#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for writing out the linkage matrix, as well as the statistics.

@author: mark
"""

import logging
import csv


logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

def write_linkage_matrix(linkage_matrix, filename):
    """This writes a linkage matrix to file.
    """
    with open(filename, 'w') as outfile:
        csv_writer = csv.writer(outfile, delimiter='\t',
                                quoting=csv.QUOTE_NONE)
        csv_writer.writerow(["Cluster ID1", "Cluster ID2", "Distance", "Number of observations"])
        for row_number in range(linkage_matrix.shape[0]):
            csv_writer.writerow(create_linkage_file_line(linkage_matrix[row_number]))
    return 0

def create_linkage_file_line(linkage_matrix_row):
    """This formats the matrix elements for reproducible writing.
    """
    return ["{:.0f}".format(linkage_matrix_row[0]),
            "{:.0f}".format(linkage_matrix_row[1]),
            "{:.7f}".format(linkage_matrix_row[2]),
            "{:.0f}".format(linkage_matrix_row[3])]