#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for testing the linkagewriter script.

@author: mark
"""

import logging
import numpy as np
import os
import unittest
import solventmapcreator.io.linkagewriter as linkagewriter

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

class LinkageWriterTestCase(unittest.TestCase):
    """Test case for the linkagewriter script.
    """
    def setUp(self):
        """Set up before tests.
        """
        self.linkage_matrix = np.array([[0., 1., 17., 2.],
                                        [4., 5., 22., 3.],
                                        [2., 3., 28., 2.],
                                        [6., 7., 33., 5.]])
        self.expected_filename = "resources/expectedlinkagematrix.csv"
    def tearDown(self):
        """Clean up after tests.
        """
        del self.linkage_matrix
        if os.path.isfile("linkagematrix.csv"):
            os.remove("linkagematrix.csv")
    def test_write_linkage_matrix(self):
        """Test to see if expected file is produced.
        """
        actual_filename = "linkagematrix.csv"
        link_mat_out = linkagewriter.write_linkage_matrix(self.linkage_matrix,
                                                          actual_filename)
        self.assertEqual(0, link_mat_out)
        with open(self.expected_filename, 'r') as exp_file:
            exp_file_lines = exp_file.readlines()
            with open(actual_filename, 'r') as act_file:
                act_file_lines = act_file.readlines()
                self.assertListEqual(act_file_lines, exp_file_lines)
    def test_create_linkage_file_line(self):
        """Test to see if line is written as expected.
        """
        expected_list = ['0', '1', '17.0000000', '2']
        actual_list = linkagewriter.create_linkage_file_line(self.linkage_matrix[0])
        self.assertListEqual(expected_list, actual_list)
